@@ -1,6 +1,6 @@
 /*
 	tofrodos.c	Converts text files between DOS and Unix formats.
-	Copyright 1996-2013 Christopher Heng. All rights reserved.
+	Copyright 1996-2022 Christopher Heng. All rights reserved.
 */
 
 /* this should always be first */
@@ -29,16 +29,8 @@
 #include <io.h>		/* chmod(), setmode(), isatty() */
 #endif
 
-#if defined(HAVE_GETOPT_H)
-#include <getopt.h>	/* optind, getopt() */
-#endif
-
-#if defined(HAVE_MKTEMP_H) && defined(MKTEMP_HEADER)
-#include MKTEMP_HEADER
-#endif
-
 #if defined(HAVE_UNISTD_H)
-#include <unistd.h>	/* chmod(), mktemp(), isatty(), chown(), readlink(), mkstemp() in some systems, (getopt()) */
+#include <unistd.h>	/* chmod(), mktemp(), isatty(), chown(), readlink(), mkstemp() in some systems, getopt() */
 #endif
 
 /* our headers */
@@ -107,7 +99,7 @@ int direction = DEFDIRECTION ; /* UNIXTODOS or DOSTOUNIX */
 int forcewrite ; /* convert even if file is not writeable */
 char * errorlogfilename ;	/* name of error log file, NULL if we're printing to stderr */
 int preserve ;	/* 1 if we are to preserve owner (Unix) and date (all) */
-char * progname = VERSN_PROGNAME ;/* name of binary (ie, argv[0]) */
+char * progname = VERSN_PROGNAME ;/* name of binary (ie, argv[0] without a path prefix) */
 int overwrite = 1 ;	/* 1 = overwrite original file, 0 = make backup */
 int verbose ;
 
